@@ -1,9 +1,6 @@
 package Dist::Zilla::Plugin::NoTabsTests;
-BEGIN {
-  $Dist::Zilla::Plugin::NoTabsTests::AUTHORITY = 'cpan:FLORA';
-}
 # ABSTRACT: (DEPRECATED) Release tests making sure hard tabs aren't used
-$Dist::Zilla::Plugin::NoTabsTests::VERSION = '0.08';
+$Dist::Zilla::Plugin::NoTabsTests::VERSION = '0.10';
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::NoTabs';
 
@@ -13,6 +10,10 @@ before register_component => sub {
     warn "!!! [NoTabsTests] is deprecated and may be removed in a future release; replace it with [Test::NoTabs]\n";
 };
 
+has '+filename' => (
+    default => sub { return 'xt/release/no-tabs.t' },
+);
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -27,7 +28,7 @@ Dist::Zilla::Plugin::NoTabsTests - (DEPRECATED) Release tests making sure hard t
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
